#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .common import _copyB
from bs4 import BeautifulSoup

def _finalTouch(soup, url):
	for item in soup.find_all("footer", class_="author-info"):
		for subitem in item.find_all("a"):
			if subitem.text and "英文版" in subitem.text:
				item.replace_with(subitem)
				break
	if 'pride.com' in url:
		for item in soup.find_all('h2'):
			item.parent.parent.insert(0, _copyB(item))
			item.decompose()
	for item in soup.find_all():
		if item.text == 'Follow TranscendingSelf and support their Fundraiser!':
			item.decompose()
	return soup


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

name = 'readee'

from .article import getArticle
from bs4 import BeautifulSoup
from opencc import OpenCC

cc = OpenCC('tw2sp')

def _formaturl(url):
	if '://' not in url:
		return "https://" + url
	return url

def export(url, content=None, **args):
	article = getArticle(url, content, args)
	if not article.text or not article.text.strip():
		raise Exception('Can not find main content')
	if args.get('toSimplified'):
		b = BeautifulSoup(str(article), 'html.parser')
		for x in b.findAll(text=True):
			x.replaceWith(cc.convert(x))
		return b
	return article